smooth_page_indicator library
Classes
- AnimatedSmoothIndicator
- Unlike SmoothPageIndicator this indicator is self-animated and it only needs to know active index
- BasicIndicatorEffect
- Basic implementation of IndicatorEffect that holds some shared properties and behaviors between different effects
- BasicIndicatorPainter
- Basic implementation of IndicatorPainter that holds some shared properties and behaviors between different painters
- ColorTransitionEffect
-
Holds painting configuration to be used by
TransitionPainter - CustomizableEffect
-
Holds painting configuration to be used by
CustomizablePainter - DefaultIndicatorColors
- Holds default colors for an indicator.
- DotBorder
- Holds dot-border painting specs
- DotDecoration
- Holds dot painting specs
- ExpandingDotsEffect
-
Holds painting configuration to be used by
ExpandingDotsPainter - IndicatorEffect
- An Abstraction for a dot-indicator animation effect
- IndicatorPainter
-
A basic abstract implementation of
customPainterto avoid overriding shouldRepaint in every painter - JumpingDotEffect
-
Holds painting configuration to be used by
JumpingDotPainter - ScaleEffect
-
Holds painting configuration to be used by
ScalePainter - ScrollingDotsEffect
-
Holds painting configuration to be used by
ScrollingDotsPainterorScrollingDotsWithFixedCenterPainter - SlideEffect
-
Holds painting configuration to be used by
SlidePainter - SmoothIndicator
- Draws dot-ish representation of pages by the number of count and animates the active page using offset
- SmoothPageIndicator
- A widget that draws a representation of pages count Inside of a PageView
- SmoothPageIndicatorTheme
- An InheritedTheme that provides default configuration to descendant SmoothPageIndicator and AnimatedSmoothIndicator widgets.
- SwapEffect
-
Holds painting configuration to be used by
SwapPainter - WormEffect
-
Holds painting configuration to be used by
WormPainter
Enums
- DotBorderType
- The variants of dot borders
- SlideType
- The Slide effect variants
- SwapType
- The swap effect variants
- WormType
- The Worm effect variants
Typedefs
- ColorBuilder = Color Function(int index)
-
Signature for a function that returns color
for each
index - OnDotClicked = void Function(int index)
- Signature for a callback function used to report dot tap-events