SmoothPageIndicatorTheme class

An InheritedTheme that provides default configuration to descendant SmoothPageIndicator and AnimatedSmoothIndicator widgets.

Usage:

MaterialApp(
  home: SmoothPageIndicatorTheme(
    effect: ExpandingDotsEffect(),
    defaultColors: DefaultIndicatorColors(
      active: Colors.blue,
      inactive: Colors.grey,
    ),
    child: MyPage(),
  ),
)
Inheritance

Constructors

SmoothPageIndicatorTheme({Key? key, IndicatorEffect? effect, DefaultIndicatorColors? defaultColors, required Widget child})
Creates a SmoothPageIndicatorTheme instance
const

Properties

child Widget
The widget below this widget in the tree.
finalinherited
defaultColors DefaultIndicatorColors?
Default colors for the indicator. If null, DefaultIndicatorColors.defaults will be used.
final
effect IndicatorEffect?
The default effect to use when none is specified. If null, WormEffect will be used as the fallback.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({IndicatorEffect? effect, DefaultIndicatorColors? colors, Widget? child}) SmoothPageIndicatorTheme
Creates a copy of this theme, replacing non-null arguments.
createElement() InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(SmoothPageIndicatorTheme? other, double t) SmoothPageIndicatorTheme
Linearly interpolates this theme's values with other.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant SmoothPageIndicatorTheme oldWidget) bool
Returns whether dependents should rebuild after this theme changes.
override
wrap(BuildContext context, Widget child) Widget
Wraps child with this theme when it is moved to a new subtree.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) SmoothPageIndicatorTheme?
Retrieves the SmoothPageIndicatorTheme from the given BuildContext. Returns null if no ancestor theme is found.
resolveDefaults(BuildContext context) → (IndicatorEffect, DefaultIndicatorColors)
Resolves the IndicatorEffect and DefaultIndicatorColors from the nearest theme, or provides fallbacks. If no effect is specified in the theme, defaults to WormEffect. If no colors are specified, uses DefaultIndicatorColors.defaults. Returns a record of (effect, colors).