effect property
The default effect to use when none is specified. If null, WormEffect will be used as the fallback.
Implementation
final IndicatorEffect? effect;
The default effect to use when none is specified. If null, WormEffect will be used as the fallback.
final IndicatorEffect? effect;