updateShouldNotify method
Returns whether dependents should rebuild after this theme changes.
Implementation
@override
/// Returns whether dependents should rebuild after this theme changes.
bool updateShouldNotify(SmoothPageIndicatorTheme oldWidget) {
return effect != oldWidget.effect ||
defaultColors != oldWidget.defaultColors;
}